ForColormap
Handbook
Source Files
Modules
Procedures
Abstract Interfaces
Derived Types
Programs
Web pages
Handbook
Reference
Web pages
Handbook
Tutorials
Installation
Basic usage
Learning
How-to
Choosing a colormap
Citing colormaps
Contributing
Getting support
Explanation
History
Projects using ForColormap
No bijection!
Reference
Articles and books
Web pages
Licenses
Gallery
About colormaps
https://en.wikipedia.org/wiki/Color_gradient
https://en.wikipedia.org/wiki/Heat_map
Ken Hughes,
"Default colormaps: Are Parula and Viridis really an improvement over Jet?"
, posted on October 1, 2019.
In Search of a Perfect Colormap
The
Data Visualisation Guide section about colours
Specific colormaps
Cubehelix (Dave Green, public domain):
https://people.phy.cam.ac.uk/dag9/CUBEHELIX/
Scientific colour maps (Fabio Crameri, MIT license):
https://www.fabiocrameri.ch/colourmaps/
https://s-ink.org/colour-map-guideline
https://s-ink.org/scientific-colour-maps
Seminar talk by Fabio Crameri about the scientific use of colour in science communication for the University of Oslo GeoHyd seminar:
https://www.youtube.com/watch?v=iDPzWARbFrs
Matplotlib colormaps (CC0 license / public domain):
Stéfan van der Walt and Nathaniel Smith:
https://bids.github.io/colormap/
Python version:
https://github.com/BIDS/colormap/blob/master/colormaps.py
Nathaniel Smith and Stéfan van der Walt,
A Better Default Colormap for Matplotlib,
SciPy 2015:
https://www.youtube.com/watch?v=xAoljeRJ3lU
Black Body colormap (CC0 license / public domain) by Kenneth Moreland:
"Color Map Advice for Scientific Visualization"
.
Colors for data scientists. Generate and refine palettes of optimally distinct colors.